@@ -11,7 +11,7 @@ our $VERSION = '0.01';
 __PACKAGE__->config(
     name                  => 'TestApp',
     default_message       => 'hi',
-    default_view          => 'Pkgconfig',
+    default_view          => 'TT::Pkgconfig',
     'View::TT::Appconfig' => {
         PRE_CHOMP          => 1,
         POST_CHOMP         => 1,
